interminebio

Package interminebio |
[hide private]
[frames] | no frames]

# Package interminebio

source code

Submodules | [hide private]
interminebio.iterators

Classes | [hide private]
| SequenceDataQuery
| RegionQuery This module allows you to construct queries that retrieve data about sequences and sequence features in biologically relevant formats, where those features are located overlapping genomic intervals.
| SequenceQuery This module allows you to construct queries that retrieve data about sequences and sequence features in biologically relevant formats.

Variables | [hide private]
| __package__ = ``'``interminebio``'``